package charInfo_width

  1. Overview
  2. Docs

Module CharInfo_width.StringSource

Parameters

module US : CamomileLibraryDefault.Camomile.UnicodeString.Type

Signature

Sourceval width : ?cfg:Cfg.widthTable option -> US.t -> (int, int) Result.result

width str returns the column width of str where str is of type Camomile.UnicodeString.Type.t and the value returned is of type (int, int) result. When Ok width returnted, width is the width of str. When Error pos returned, pos is the offset of the left most unprintable character in str.